; DRAW draws an 8*8 box onto the screen
; INPUTS: a - xpixel, b - ypixel
; DESTROYS: a, b
; RETURNS: nothing

DRAW:
	di				;disable interupts before messing with the lcd driver
	call	wait			;wait for the lcd driver to become avaliable
	out	(10h), a		;set the x location of the lcd driver's pen
	ld	a, b
	call	wait
	out	(10h), a		;set the y location of the lcd driver's pen
	ld	b, 8
	ld	a, 0FDh
DBOX:
	call	wait
	out	(11h), a		;draw contents of 'a' to the screen
	djnz	DBOX
	ei
	ret

; ERASE erases an 8*8 box on the screen
; INPUTS: a - xpixel, b - ypixel
; DESTROYS: a, b
; RETURNS: nothing

ERASE:
	di
	call	wait
	out	(10h), a
	ld	a, b
	call	wait
	out	(10h), a
	ld	b, 8
	ld	a, 00h
EBox:
	call	wait
	out	(11h), a
	djnz	EBox
	ei
	ret

; wait waits for the lcd driver and
; returns when it is not busy
; INPUTS: none 
; DESTROYS: nothing
; RETURNS: nothing

wait:
	push	af
	in	a, (10h)		;get lcd driver status in a
	bit	7, a			;bit 7 is set if lcd driver is busy
	jp	nz, wait
	pop	af
	ret

; Direct input from arrows 
; INPUTS: none
; DESTROYS: a, hl
; RETURNS (in a): 
; 0 - no arrow pressed
; 1 - down 
; 2 - left
; 3 - up
; 4 - right
; debounce flags (these are used to debounce the keys and
; are set when a key is pressed and reset after key is done being pressed):
UPr:
	.db	0
DPr:
	.db	0
LPr:
	.db	0
RPr:
	.db	0
GARROW:
	ld	a, 11111110b
	out	(01h), a		;set keyboard group
	in	a, (01h)		;get keyboard status
	push	af			;save 'a' for later use
	ld	hl, DPr			;get address of DPr for later
	bit	0, a			;check if down key was pressed
	jp	z, PR1			
	ld	(hl), 0			;if not being pressed reset the debounce mechanism (not sure what to call it)
	jp	NP1			;then check the next arrow key

PR1:
; pressd
	call	PRESSCHK		
	cp	0			;check if key press has already been taken care of
	jp	z, NP1
	pop	af			;down was pressed so fix stack
	ld	a, 1			;ld a with 1 to say down was pressed
	jp	xtGAR			;jump to exit code

NP1:
; NOT PRESSD (so check next key)
	pop	af
	push	af
	bit	1, a
	ld	hl, LPr
	jp	z, PR2
	ld	(hl), 0
	jp	NP2

PR2:
	call	PRESSCHK
	cp	0
	jp	z, NP2
	pop	af
	ld	a, 2
	jp	xtGAR

NP2:
	pop	af
	push	af
	bit	2, a
	ld	hl, RPr
	jp	z, PR3
	ld	(hl), 0
	jp	NP3

PR3:
	call	PRESSCHK
	cp	0
	jp	z, NP3
	pop	af
	ld	a, 4
	jp	xtGAR

NP3:
	pop	af
	ld	hl, UPr
	bit	3, a
	jp	z, PR4
	ld	(hl), 0
	jp	NO			;no key was pressed

PR4:
	call	PRESSCHK
	cp	0
	jp	z, NO
	ld	a, 3
	jp	xtGAR

;PRESSCHK is a small sub-subroutine used in GARROW to check the debounce flags 
;input: hl - address of a debounce flags (UPr, DPr, LPr, RPr)
;destroy: a
;returns (in a): 0 - key already pressed, 1 - good to go
PRESSCHK:
	xor	a
	cp	(hl)			;check if key was already pressed 1=pressed
	ret	nz			;ret if already pressed
	ld	(hl), 1			;if not already pressed then set flag for next time
	inc	a
	ret

NO:
	xor	a			;return 0 to say nothing was pressed
xtGAR:
	ret				;just return... stack and return value are already taken care of

; GCLR returns 1 in a if clr was pressed
; INPUTS: none
; DESTROYS: a
; RETURNS: in a
;		0 - clr was not pressed
;		1 - clr was pressed
GCLR:
	ld	a, 11111101b	
	out	(01h), a		;activate group with clr in it
	in	a, (01h)		;get key status
	bit	6, a			;check clr bit
	jp	nz, NCLR		;clr was not pressed
	ld	a, 1			;clr was pressed so ret 1
	jp	xtGCLR

NCLR:
	xor	a			;clr wasn't pressed so ret 0
xtGCLR:
	ret

